// BWFileList -- maintains lists of graphic files

// Copyright (C) 2005 Borkware, LLC
// We use the BSD License.  Check out http://borkware.com/license

#import <Foundation/Foundation.h>

// for each file found, there's one of these

@interface BWFileEntry : NSObject
{
    NSString	*root;		// base path
    NSString	*relativePath;	// where the file lives relative to the base
    NSString	*fileName;
    int		 fileSize;
    NSMutableDictionary *properties; // unknown KVC values end up here
}

+ (BWFileEntry *) newEntryWithPath: (NSString *) path
                           basedAt: (NSString *) at;

- (id) initWithRoot: (NSString *) r     relativePath: (NSString *) rpath
           fileName: (NSString *) name  fileSize: (int) size;
- (NSString *) fullPath;
- (NSString *) fileName;
- (int) fileSize;

- (NSComparisonResult) compareByName: (BWFileEntry *) thing2;

@end // BWFileEntry


// array of file entries

@interface BWFileList : NSObject
{
    NSString		*basePath;  // where the files came from
    NSMutableArray	*fileList;  // set of BWFileEntries
}

// walk the directory and build file entries
+ (BWFileList *) loadFromDirectory: (NSString *) pathName  deeply: (BOOL) deep;

- (int) count;
- (BWFileEntry *) getFileAt: (int) index;
- (void) removeFileAt: (int) index;
- (void) sortByFileName;

- (id) initWithBasePath: (NSString *) base 
       relativeFileList: (NSArray *) list;

@end // BWFileList


