// BWSearchArrayController -- Array controller that supports search-box
//                            limiting.

// Copyright (C) 2005 Borkware, LLC
// We use the BSD License.  Check out http://borkware.com/license

#import "BWSearchArrayController.h"

// this work is done for us in Mac OS X 10.4 and beyond


@implementation BWSearchArrayController

// returns an array containing the content of the objects arranged
// with the user's critera entered into the search box thingie

- (NSArray *) arrangeObjects: (NSArray *) objects
{
    // result of the filtering
    NSArray *returnObjects = objects;

    // if there is a search string, use it to compare with the
    // search field string

    if (searchString != nil) {

        // where to store the filtered 
        NSMutableArray *filteredObjects;
        filteredObjects = [NSMutableArray arrayWithCapacity: [objects count]];

        // walk the enumerator 
        NSEnumerator *enumerator = [objects objectEnumerator];

        id item; // actully BWFileEntries
        while (item = [enumerator nextObject]) {

            // get the filename from the entry
            NSString *filename;
            filename = [item valueForKeyPath: @"fileName"];

            // see if the file name matches the search string
            NSRange range;
            range = [filename rangeOfString: searchString
                              options: NSCaseInsensitiveSearch];
            
            // found the search string in the file name, add it to
            // the result set
            if (range.location != NSNotFound) {
                [filteredObjects addObject: item];
            }
        }

        returnObjects = filteredObjects;
    }

    return (returnObjects);

} // arrangeObjets



// called by the search box

- (void) setSearchString: (NSString *) string
{
    [searchString release];

    if ([string length] == 0) {
        searchString = nil;
    } else {
        searchString = [string copy];
    }

} // setSearchString



// called by the search box too

- (void) search: (id) sender
{
    [self setSearchString: [sender stringValue]];
    [self rearrangeObjects];

} // search


@end // BWSearchArrayController

